@@ -15,28 +15,24 @@
 
 import sys
 
+import eventlet
+
+eventlet.monkey_patch()
+
+from neutron.agent.common import config
+from neutron.agent.linux import interface
 from neutron.common import config as common_config
-from neutron.conf.agent import common as config
-from neutron_lib import rpc as n_rpc
+from neutron.common import rpc as n_rpc
+from neutron.openstack.common import service
 from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_service import service
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.agent import agent_manager as manager
 from neutron_lbaas.services.loadbalancer import constants
 
-LOG = logging.getLogger(__name__)
-
 OPTS = [
     cfg.IntOpt(
         'periodic_interval',
         default=10,
-        deprecated_for_removal=True,
-        deprecated_since='Queens',
-        deprecated_reason='The neutron-lbaas project is now deprecated. '
-                          'See: https://wiki.openstack.org/wiki/Neutron/LBaaS/'
-                          'Deprecation',
         help=_('Seconds between periodic task runs')
     )
 ]
@@ -57,18 +53,13 @@ def main():
     cfg.CONF.register_opts(OPTS)
     cfg.CONF.register_opts(manager.OPTS)
     # import interface options just in case the driver uses namespaces
-    config.register_interface_opts(cfg.CONF)
-    config.register_external_process_opts(cfg.CONF)
+    cfg.CONF.register_opts(interface.OPTS)
     config.register_interface_driver_opts_helper(cfg.CONF)
     config.register_agent_state_opts_helper(cfg.CONF)
     config.register_root_helper(cfg.CONF)
 
     common_config.init(sys.argv[1:])
     config.setup_logging()
-    config.setup_privsep()
-
-    LOG.warning('neutron-lbaas is now deprecated. See: '
-                'https://wiki.openstack.org/wiki/Neutron/LBaaS/Deprecation')
 
     mgr = manager.LbaasAgentManager(cfg.CONF)
     svc = LbaasAgentService(
@@ -76,4 +67,4 @@ def main():
         topic=constants.LOADBALANCER_AGENTV2,
         manager=mgr
     )
-    service.launch(cfg.CONF, svc).wait()
+    service.launch(svc).wait()
