@@ -13,26 +13,28 @@
 #    under the License.
 
 from barbicanclient import client as barbican_client
+from keystoneclient import session
+from keystoneclient.v2_0 import client as v2_client
+from keystoneclient.v3 import client as v3_client
+from neutron.i18n import _LI, _LW, _LE
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
-from stevedore import driver as stevedore_driver
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.common.cert_manager import cert_manager
 
 LOG = logging.getLogger(__name__)
 
 CONF = cfg.CONF
+cfg.CONF.import_group('keystone_authtoken', 'keystonemiddleware.auth_token')
 
 
 class Cert(cert_manager.Cert):
     """Representation of a Cert based on the Barbican CertificateContainer."""
-
     def __init__(self, cert_container):
         if not isinstance(cert_container,
                           barbican_client.containers.CertificateContainer):
-            raise TypeError(_(
+            raise TypeError(_LE(
                 "Retrieved Barbican Container is not of the correct type "
                 "(certificate)."))
         self._cert_container = cert_container
@@ -57,20 +59,72 @@ class Cert(cert_manager.Cert):
             return self._cert_container.private_key_passphrase.payload
 
 
+class BarbicanKeystoneAuth(object):
+    _keystone_session = None
+    _barbican_client = None
+
+    @classmethod
+    def _get_keystone_session(cls):
+        """Initializes a Keystone session.
+
+        :return: a Keystone Session object
+        :raises Exception: if the session cannot be established
+        """
+        if not cls._keystone_session:
+            try:
+                if CONF.keystone_authtoken.auth_version.lower() == 'v2':
+                    kc = v2_client.Client(
+                        username=CONF.keystone_authtoken.admin_user,
+                        password=CONF.keystone_authtoken.admin_password,
+                        tenant_name=CONF.keystone_authtoken.admin_tenant_name,
+                        auth_url=CONF.keystone_authtoken.auth_uri
+                    )
+                elif CONF.keystone_authtoken.auth_version.lower() == 'v3':
+                    kc = v3_client.Client(
+                        username=CONF.keystone_authtoken.admin_user,
+                        password=CONF.keystone_authtoken.admin_password,
+                        tenant_name=CONF.keystone_authtoken.admin_tenant_name,
+                        auth_url=CONF.keystone_authtoken.auth_uri
+                    )
+                else:
+                    raise Exception('Unknown authentication version')
+                cls._keystone_session = session.Session(auth=kc)
+            except Exception:
+                # Keystone sometimes masks exceptions strangely -- this will
+                #  reraise the original exception, while also providing useful
+                #  feedback in the logs for debugging
+                with excutils.save_and_reraise_exception():
+                    LOG.exception(_LE("Error creating Keystone session"))
+        return cls._keystone_session
+
+    @classmethod
+    def get_barbican_client(cls):
+        """Creates a Barbican client object.
+
+        :return: a Barbican Client object
+        :raises Exception: if the client cannot be created
+        """
+        if not cls._barbican_client:
+            try:
+                cls._barbican_client = barbican_client.Client(
+                    session=cls._get_keystone_session()
+                )
+            except Exception:
+                # Barbican (because of Keystone-middleware) sometimes masks
+                #  exceptions strangely -- this will reraise the original
+                #  exception, while also providiung useful feedback in the
+                #  logs for debugging
+                with excutils.save_and_reraise_exception():
+                    LOG.exception(_LE("Error creating Barbican client"))
+        return cls._barbican_client
+
+
 class CertManager(cert_manager.CertManager):
     """Certificate Manager that wraps the Barbican client API."""
-
-    def __init__(self):
-        super(CertManager, self).__init__()
-        self.auth = stevedore_driver.DriverManager(
-            namespace='neutron_lbaas.cert_manager.barbican_auth',
-            name=cfg.CONF.certificates.barbican_auth,
-            invoke_on_load=True,
-        ).driver
-
-    def store_cert(self, project_id, certificate, private_key,
-                   intermediates=None, private_key_passphrase=None,
-                   expiration=None, name='LBaaS TLS Cert'):
+    @staticmethod
+    def store_cert(certificate, private_key, intermediates=None,
+                   private_key_passphrase=None, expiration=None,
+                   name='Octavia TLS Cert', **kwargs):
         """Stores a certificate in the certificate manager.
 
         :param certificate: PEM encoded TLS certificate
@@ -83,10 +137,9 @@ class CertManager(cert_manager.CertManager):
         :returns: the container_ref of the stored cert
         :raises Exception: if certificate storage fails
         """
+        connection = BarbicanKeystoneAuth.get_barbican_client()
 
-        connection = self.auth.get_barbican_client(project_id)
-
-        LOG.info((
+        LOG.info(_LI(
             "Storing certificate container '{0}' in Barbican."
         ).format(name))
 
@@ -134,38 +187,39 @@ class CertManager(cert_manager.CertManager):
         #  feedback in the logs for debugging
         except Exception:
             for secret in [certificate_secret, private_key_secret,
-                           intermediates_secret, pkp_secret]:
+                      intermediates_secret, pkp_secret]:
                 if secret and secret.secret_ref:
                     old_ref = secret.secret_ref
                     try:
                         secret.delete()
-                        LOG.info((
+                        LOG.info(_LI(
                             "Deleted secret {0} ({1}) during rollback."
                         ).format(secret.name, old_ref))
                     except Exception:
-                        LOG.warning((
+                        LOG.warning(_LW(
                             "Failed to delete {0} ({1}) during rollback. This "
                             "is probably not a problem."
                         ).format(secret.name, old_ref))
             with excutils.save_and_reraise_exception():
-                LOG.exception("Error storing certificate data")
+                LOG.exception(_LE("Error storing certificate data"))
 
-    def get_cert(self, project_id, cert_ref, resource_ref,
-                 check_only=False, service_name='lbaas'):
+    @staticmethod
+    def get_cert(cert_ref, service_name='Octavia', resource_ref=None,
+                 check_only=False, **kwargs):
         """Retrieves the specified cert and registers as a consumer.
 
         :param cert_ref: the UUID of the cert to retrieve
+        :param service_name: Friendly name for the consuming service
         :param resource_ref: Full HATEOAS reference to the consuming resource
         :param check_only: Read Certificate data without registering
-        :param service_name: Friendly name for the consuming service
 
-        :returns: octavia.certificates.common.Cert representation of the
+        :return: octavia.certificates.common.Cert representation of the
                  certificate data
         :raises Exception: if certificate retrieval fails
         """
-        connection = self.auth.get_barbican_client(project_id)
+        connection = BarbicanKeystoneAuth.get_barbican_client()
 
-        LOG.info((
+        LOG.info(_LI(
             "Loading certificate container {0} from Barbican."
         ).format(cert_ref))
         try:
@@ -182,21 +236,22 @@ class CertManager(cert_manager.CertManager):
             return Cert(cert_container)
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.exception("Error getting {0}".format(cert_ref))
+                LOG.exception(_LE("Error getting {0}").format(cert_ref))
 
-    def delete_cert(self, project_id, cert_ref, resource_ref,
-                    service_name='lbaas'):
+    @staticmethod
+    def delete_cert(cert_ref, service_name='Octavia', resource_ref=None,
+                    **kwargs):
         """Deregister as a consumer for the specified cert.
 
         :param cert_ref: the UUID of the cert to retrieve
         :param service_name: Friendly name for the consuming service
-        :param lb_id: Loadbalancer id for building resource consumer URL
+        :param resource_ref: Full HATEOAS reference to the consuming resource
 
         :raises Exception: if deregistration fails
         """
-        connection = self.auth.get_barbican_client(project_id)
+        connection = BarbicanKeystoneAuth.get_barbican_client()
 
-        LOG.info((
+        LOG.info(_LI(
             "Deregistering as a consumer of {0} in Barbican."
         ).format(cert_ref))
         try:
@@ -207,6 +262,33 @@ class CertManager(cert_manager.CertManager):
             )
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.exception((
+                LOG.exception(_LE(
                     "Error deregistering as a consumer of {0}"
                 ).format(cert_ref))
+
+    @staticmethod
+    def _actually_delete_cert(cert_ref):
+        """Deletes the specified cert. Very dangerous. Do not recommend.
+
+        :param cert_ref: the UUID of the cert to delete
+        :raises Exception: if certificate deletion fails
+        """
+        connection = BarbicanKeystoneAuth.get_barbican_client()
+
+        LOG.info(_LI(
+            "Recursively deleting certificate container {0} from Barbican."
+        ).format(cert_ref))
+        try:
+            certificate_container = connection.containers.get(cert_ref)
+            certificate_container.certificate.delete()
+            if certificate_container.intermediates:
+                certificate_container.intermediates.delete()
+            if certificate_container.private_key_passphrase:
+                certificate_container.private_key_passphrase.delete()
+            certificate_container.private_key.delete()
+            certificate_container.delete()
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                LOG.exception(_LE(
+                    "Error recursively deleting certificate container {0}"
+                ).format(cert_ref))
