@@ -13,19 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from cryptography.hazmat import backends
-from cryptography.hazmat.primitives import serialization
-from cryptography import x509
-from oslo_log import log as logging
-from oslo_utils import encodeutils
-
 import neutron_lbaas.common.exceptions as exceptions
+from OpenSSL import crypto
+from OpenSSL import SSL
+import pyasn1.codec.der.decoder as decoder
+import pyasn1_modules.rfc2459 as rfc2459
+import six
+
 
 X509_BEG = "-----BEGIN CERTIFICATE-----"
 X509_END = "-----END CERTIFICATE-----"
 
-LOG = logging.getLogger(__name__)
-
 
 def validate_cert(certificate, private_key=None,
                   private_key_passphrase=None, intermediates=None):
@@ -41,30 +39,29 @@ def validate_cert(certificate, private_key=None,
     :param intermediates: PEM encoded intermediate certificates
     :returns: boolean
     """
-
-    cert = _get_x509_from_pem_bytes(certificate)
+    x509 = _get_x509_from_pem_bytes(certificate)
     if intermediates:
         for x509Pem in _split_x509s(intermediates):
             _get_x509_from_pem_bytes(x509Pem)
     if private_key:
         pkey = _read_privatekey(private_key, passphrase=private_key_passphrase)
-        pknum = pkey.public_key().public_numbers()
-        certnum = cert.public_key().public_numbers()
-        if pknum != certnum:
+        ctx = SSL.Context(SSL.TLSv1_METHOD)
+        ctx.use_certificate(x509)
+        try:
+            ctx.use_privatekey(pkey)
+            ctx.check_privatekey()
+        except Exception:
             raise exceptions.MisMatchedKey
     return True
 
 
 def _read_privatekey(privatekey_pem, passphrase=None):
-    if passphrase is not None:
-        passphrase = encodeutils.to_utf8(passphrase)
-    privatekey_pem = privatekey_pem.encode('ascii')
-
-    try:
-        return serialization.load_pem_private_key(privatekey_pem, passphrase,
-                                                  backends.default_backend())
-    except Exception:
-        raise exceptions.NeedsPassphrase
+    def cb(*args):
+        if passphrase:
+            return six.b(passphrase).encode('utf-8')
+        else:
+            raise exceptions.NeedsPassphrase
+    return crypto.load_privatekey(crypto.FILETYPE_PEM, privatekey_pem, cb)
 
 
 def _split_x509s(x509Str):
@@ -92,42 +89,21 @@ def _split_x509s(x509Str):
                 inside_x509 = True
 
 
-def _read_pyca_private_key(private_key, private_key_passphrase=None):
-    kw = {"password": None,
-          "backend": backends.default_backend()}
-    if private_key_passphrase is not None:
-        kw["password"] = encodeutils.to_utf8(private_key_passphrase)
-    else:
-        kw["password"] = None
-    private_key = encodeutils.to_utf8(private_key)
-    try:
-        pk = serialization.load_pem_private_key(private_key, **kw)
-        return pk
-    except TypeError as ex:
-        if len(ex.args) > 0 and ex.args[0].startswith("Password"):
-            raise exceptions.NeedsPassphrase
-
-
 def dump_private_key(private_key, private_key_passphrase=None):
     """
-    Parses encrypted key to provide an unencrypted version in PKCS8
+    Parses encrypted key to provide an unencrypted version
 
     :param private_key: private key
     :param private_key_passphrase: private key passphrase
-    :returns: Unencrypted private key in PKCS8
+    :return: Unencrypted private key
     """
-
-    # re encode the key as unencrypted PKCS8
-    pk = _read_pyca_private_key(private_key,
-                                private_key_passphrase=private_key_passphrase)
-    key = pk.private_bytes(encoding=serialization.Encoding.PEM,
-                           format=serialization.PrivateFormat.PKCS8,
-                           encryption_algorithm=serialization.NoEncryption())
-    return key
+    pkey = _read_privatekey(private_key, private_key_passphrase)
+    return crypto.dump_privatekey(crypto.FILETYPE_PEM, pkey)
 
 
 def get_host_names(certificate):
-    """Extract the host names from the Pem encoded X509 certificate
+    """
+    Extract the host names from the Pem encoded X509 certificate
 
     :param certificate: A PEM encoded certificate
     :returns: A dictionary containing the following keys:
@@ -136,29 +112,25 @@ def get_host_names(certificate):
     'dns_names' is a list of dNSNames (possibly empty) from
     the SubjectAltNames of the certificate.
     """
-    try:
-        certificate = certificate.encode('ascii')
 
-        cert = _get_x509_from_pem_bytes(certificate)
-        cn = cert.subject.get_attributes_for_oid(x509.OID_COMMON_NAME)[0]
-        host_names = {
-            'cn': cn.value.lower(),
-            'dns_names': []
-        }
-        try:
-            ext = cert.extensions.get_extension_for_oid(
-                x509.OID_SUBJECT_ALTERNATIVE_NAME
-            )
-            host_names['dns_names'] = ext.value.get_values_for_type(
-                x509.DNSName)
-        except x509.ExtensionNotFound:
-            LOG.debug("%s extension not found",
-                      x509.OID_SUBJECT_ALTERNATIVE_NAME)
+    x509 = _get_x509_from_pem_bytes(certificate)
+    hostNames = {}
+    if hasattr(x509.get_subject(), 'CN'):
+        hostNames['cn'] = x509.get_subject().CN
+    hostNames['dns_names'] = []
+    num_exts = x509.get_extension_count()
+    for i in range(0, num_exts):
+        ext = x509.get_extension(i)
+        if ext.get_short_name() == 'subjectAltName':
+            data = ext.get_data()
 
-        return host_names
-    except Exception:
-        LOG.exception("Unreadable certificate.")
-        raise exceptions.UnreadableCert
+            general_names_container = decoder.decode(
+                data, asn1Spec=rfc2459.GeneralNames())
+            for general_names in general_names_container[0]:
+                if general_names.getName() == 'dNSName':
+                    octets = general_names.getComponent().asOctets()
+                    hostNames['dns_names'].append(octets.encode('utf-8'))
+    return hostNames
 
 
 def _get_x509_from_pem_bytes(certificate_pem):
@@ -166,12 +138,11 @@ def _get_x509_from_pem_bytes(certificate_pem):
     Parse X509 data from a PEM encoded certificate
 
     :param certificate_pem: Certificate in PEM format
-    :returns: crypto high-level x509 data from the PEM string
+    :returns: pyOpenSSL high-level x509 data from the PEM string
     """
-    certificate = encodeutils.to_utf8(certificate_pem)
     try:
-        x509cert = x509.load_pem_x509_certificate(certificate,
-                                                  backends.default_backend())
+        x509 = crypto.load_certificate(crypto.FILETYPE_PEM,
+                                       certificate_pem)
     except Exception:
         raise exceptions.UnreadableCert
-    return x509cert
+    return x509
