@@ -17,26 +17,28 @@ from neutron.api.v2 import attributes
 from neutron.callbacks import events
 from neutron.callbacks import registry
 from neutron.callbacks import resources
+from neutron.common import constants as n_constants
+from neutron.common import exceptions as n_exc
 from neutron.db import common_db_mixin as base_db
 from neutron.db import model_base
 from neutron.db import models_v2
 from neutron.db import servicetype_db as st_db
 from neutron import manager
+from neutron.openstack.common import uuidutils
 from neutron.plugins.common import constants
-from neutron_lib import constants as n_constants
-from neutron_lib import exceptions as n_exc
 from oslo_db import exception
+from oslo_log import log as logging
 from oslo_utils import excutils
-from oslo_utils import uuidutils
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import exc
 from sqlalchemy.orm import validates
 
-from neutron_lbaas._i18n import _, _LE
 from neutron_lbaas.extensions import loadbalancer
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 
+LOG = logging.getLogger(__name__)
+
 
 class SessionPersistence(model_base.BASEV2):
 
@@ -350,7 +352,7 @@ class LoadBalancerPluginDb(loadbalancer.LoadBalancerPluginBase,
 
     def create_vip(self, context, vip):
         v = vip['vip']
-        tenant_id = v['tenant_id']
+        tenant_id = self._get_tenant_id_for_create(context, v)
 
         with context.session.begin(subtransactions=True):
             if v['pool_id']:
@@ -581,9 +583,10 @@ class LoadBalancerPluginDb(loadbalancer.LoadBalancerPluginBase,
     def create_pool(self, context, pool):
         v = pool['pool']
 
+        tenant_id = self._get_tenant_id_for_create(context, v)
         with context.session.begin(subtransactions=True):
             pool_db = Pool(id=uuidutils.generate_uuid(),
-                           tenant_id=v['tenant_id'],
+                           tenant_id=tenant_id,
                            name=v['name'],
                            description=v['description'],
                            subnet_id=v['subnet_id'],
@@ -713,13 +716,14 @@ class LoadBalancerPluginDb(loadbalancer.LoadBalancerPluginBase,
 
     def create_member(self, context, member):
         v = member['member']
+        tenant_id = self._get_tenant_id_for_create(context, v)
 
         try:
             with context.session.begin(subtransactions=True):
                 # ensuring that pool exists
                 self._get_resource(context, Pool, v['pool_id'])
                 member_db = Member(id=uuidutils.generate_uuid(),
-                                   tenant_id=v['tenant_id'],
+                                   tenant_id=tenant_id,
                                    pool_id=v['pool_id'],
                                    address=v['address'],
                                    protocol_port=v['protocol_port'],
@@ -786,10 +790,11 @@ class LoadBalancerPluginDb(loadbalancer.LoadBalancerPluginBase,
 
     def create_health_monitor(self, context, health_monitor):
         v = health_monitor['health_monitor']
+        tenant_id = self._get_tenant_id_for_create(context, v)
         with context.session.begin(subtransactions=True):
             # setting ACTIVE status since healthmon is shared DB object
             monitor_db = HealthMonitor(id=uuidutils.generate_uuid(),
-                                       tenant_id=v['tenant_id'],
+                                       tenant_id=tenant_id,
                                        type=v['type'],
                                        delay=v['delay'],
                                        timeout=v['timeout'],
@@ -833,13 +838,6 @@ class LoadBalancerPluginDb(loadbalancer.LoadBalancerPluginBase,
                                     self._make_health_monitor_dict,
                                     filters=filters, fields=fields)
 
-    def check_subnet_in_use(self, context, subnet_id):
-        query = context.session.query(Pool).filter_by(subnet_id=subnet_id)
-        if query.count():
-            pool_id = query.one().id
-            raise n_exc.SubnetInUse(
-                reason=_LE("Subnet is used by loadbalancer pool %s") % pool_id)
-
 
 def _prevent_lbaas_port_delete_callback(resource, event, trigger, **kwargs):
     context = kwargs['context']
@@ -849,20 +847,3 @@ def _prevent_lbaas_port_delete_callback(resource, event, trigger, **kwargs):
                          constants.LOADBALANCER)
     if lbaasplugin and port_check:
         lbaasplugin.prevent_lbaas_port_deletion(context, port_id)
-
-
-def is_subnet_in_use_callback(resource, event, trigger, **kwargs):
-    service = manager.NeutronManager.get_service_plugins().get(
-        constants.LOADBALANCER)
-    if service:
-        context = kwargs.get('context')
-        subnet_id = kwargs.get('subnet_id')
-        service.check_subnet_in_use(context, subnet_id)
-
-
-def subscribe():
-    registry.subscribe(is_subnet_in_use_callback,
-                       resources.SUBNET, events.BEFORE_DELETE)
-
-
-subscribe()
