@@ -1,5 +1,5 @@
 
-# Copyright 2015 Citrix Systems, Inc.
+# Copyright 2014 Citrix Systems, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -15,17 +15,18 @@
 
 
 import abc
-
-from neutron_lib import constants
-from neutron_lib import context as ncontext
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_service import service
 
-from neutron_lbaas._i18n import _
+
+from neutron import context as ncontext
+from neutron.i18n import _LE
+from neutron.openstack.common import service
+from neutron.plugins.common import constants
+
 from neutron_lbaas.drivers import driver_base
-from neutron_lbaas.drivers import driver_mixins
-from neutron_lbaas.drivers.netscaler import ncc_client
+from neutron_lbaas.drivers.driver_mixins import BaseManagerMixin
+from neutron_lbaas.services.loadbalancer.drivers.netscaler import ncc_client
 
 DEFAULT_PERIODIC_TASK_INTERVAL = "2"
 DEFAULT_STATUS_COLLECTION = "True"
@@ -33,7 +34,6 @@ DEFAULT_PAGE_SIZE = "300"
 DEFAULT_IS_SYNCRONOUS = "True"
 
 PROV = "provisioning_status"
-NETSCALER = "netscaler"
 
 LOG = logging.getLogger(__name__)
 
@@ -48,7 +48,6 @@ NETSCALER_CC_OPTS = [
     ),
     cfg.StrOpt(
         'netscaler_ncc_password',
-        secret=True,
         help=_('Password to login to the NetScaler Control Center Server.'),
     ),
     cfg.StrOpt(
@@ -63,12 +62,6 @@ NETSCALER_CC_OPTS = [
         help=_('Setting for option to enable synchronous operations'
                'NetScaler Control Center Server.'),
     ),
-    cfg.StrOpt(
-        'netscaler_ncc_cleanup_mode',
-        help=_(
-            'Setting to enable/disable cleanup mode for NetScaler Control '
-            'Center Server'),
-    ),
     cfg.StrOpt(
         'netscaler_status_collection',
         default=DEFAULT_STATUS_COLLECTION + "," + DEFAULT_PAGE_SIZE,
@@ -121,11 +114,9 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
         ncc_uri = self.driver_conf.netscaler_ncc_uri
         ncc_username = self.driver_conf.netscaler_ncc_username
         ncc_password = self.driver_conf.netscaler_ncc_password
-        ncc_cleanup_mode = cfg.CONF.netscaler_driver.netscaler_ncc_cleanup_mode
         self.client = ncc_client.NSClient(ncc_uri,
                                           ncc_username,
-                                          ncc_password,
-                                          ncc_cleanup_mode)
+                                          ncc_password)
 
     def _init_managers(self):
         self.load_balancer = NetScalerLoadBalancerManager(self)
@@ -144,22 +135,8 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
         if is_status_collection.lower() == "false":
             self.is_status_collection = False
         self.pagesize_status_collection = pagesize_status_collection
-
-        self._init_pending_status_tracker()
-
         NetScalerStatusService(self).start()
 
-    def _init_pending_status_tracker(self):
-        # Initialize PROVISIONING_STATUS_TRACKER for loadbalancers in
-        # pending state
-        db_lbs = self.plugin.db.get_loadbalancers(
-            self.admin_ctx)
-        for db_lb in db_lbs:
-            if ((db_lb.id not in PROVISIONING_STATUS_TRACKER) and
-                (db_lb.provider.provider_name == NETSCALER) and
-                    (db_lb.provisioning_status.startswith("PENDING_"))):
-                PROVISIONING_STATUS_TRACKER.append(db_lb.id)
-
     def collect_provision_status(self):
 
         msg = ("Collecting status ", self.periodic_task_interval)
@@ -200,7 +177,7 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
                 self.load_balancer.successful_completion(
                     self.admin_ctx, db_lb, delete=True)
             except Exception:
-                LOG.error("error with successful completion")
+                LOG.error(_LE("error with successful completion"))
             PROVISIONING_STATUS_TRACKER.remove(lb_id)
             return
         else:
@@ -295,7 +272,7 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
                     entity_manager.failed_completion(
                         self.admin_ctx, db_entity)
                 except Exception:
-                    LOG.error("error with failed completion")
+                    LOG.error(_LE("error with failed completion"))
                 return
 
         if db_entity.provisioning_status == constants.PENDING_DELETE:
@@ -311,7 +288,7 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
                 entity_manager.successful_completion(
                     self.admin_ctx, db_entity, delete=True)
             except Exception:
-                LOG.error("error with successful completion")
+                LOG.error(_LE("error with successful completion"))
             return
 
         if entity_status[PROV] != constants.ACTIVE:
@@ -324,23 +301,18 @@ class NetScalerLoadBalancerDriverV2(driver_base.LoadBalancerBaseDriver):
             entity_manager.successful_completion(
                 self.admin_ctx, db_entity)
         except Exception:
-            LOG.error("error with successful completion")
+            LOG.error(_LE("error with successful completion"))
 
         return
 
 
-class NetScalerCommonManager(driver_mixins.BaseManagerMixin):
+class NetScalerCommonManager(BaseManagerMixin):
 
     def __init__(self, driver):
         super(NetScalerCommonManager, self).__init__(driver)
         self.payload_preparer = PayloadPreparer()
         self.client = self.driver.client
-
         self.is_synchronous = self.driver.driver_conf.is_synchronous
-        if self.is_synchronous.lower() == "false":
-            self.is_synchronous = False
-        else:
-            self.is_synchronous = True
 
     def create(self, context, obj):
         LOG.debug("%s, create %s", self.__class__.__name__, obj.id)
@@ -350,9 +322,9 @@ class NetScalerCommonManager(driver_mixins.BaseManagerMixin):
                 self.successful_completion(context, obj)
             else:
                 self.track_provision_status(obj)
-        except Exception:
+        except Exception as e:
             self.failed_completion(context, obj)
-            raise
+            raise e
 
     def update(self, context, old_obj, obj):
         LOG.debug("%s, update %s", self.__class__.__name__, old_obj.id)
@@ -362,9 +334,9 @@ class NetScalerCommonManager(driver_mixins.BaseManagerMixin):
                 self.successful_completion(context, obj)
             else:
                 self.track_provision_status(obj)
-        except Exception:
+        except Exception as e:
             self.failed_completion(context, obj)
-            raise
+            raise e
 
     def delete(self, context, obj):
         LOG.debug("%s, delete %s", self.__class__.__name__, obj.id)
@@ -374,9 +346,9 @@ class NetScalerCommonManager(driver_mixins.BaseManagerMixin):
                 self.successful_completion(context, obj, delete=True)
             else:
                 self.track_provision_status(obj)
-        except Exception:
+        except Exception as e:
             self.failed_completion(context, obj)
-            raise
+            raise e
 
     def track_provision_status(self, obj):
         for lb in self._get_loadbalancers(obj):
@@ -421,7 +393,7 @@ class NetScalerLoadBalancerManager(NetScalerCommonManager,
         vip_subnet_id = lb_obj.vip_subnet_id
         network_info = self.payload_preparer.\
             get_network_info(context, self.driver.plugin, vip_subnet_id)
-        ncc_lb.update(network_info)
+        ncc_lb = dict(ncc_lb.items() + network_info.items())
         msg = _("NetScaler driver lb creation: %s") % repr(ncc_lb)
         LOG.debug(msg)
         resource_path = "%s/%s" % (RESOURCE_PREFIX, LBS_RESOURCE)
@@ -544,7 +516,7 @@ class NetScalerMemberManager(NetScalerCommonManager,
         network_info = (self.payload_preparer.
                         get_network_info(context, self.driver.plugin,
                                          subnet_id))
-        ncc_member.update(network_info)
+        ncc_member = dict(ncc_member.items() + network_info.items())
         msg = _("NetScaler driver member creation: %s") % repr(ncc_member)
         LOG.debug(msg)
         parent_pool_id = member.pool.id
@@ -680,10 +652,10 @@ class PayloadPreparer(object):
             'lb_algorithm': pool.lb_algorithm,
             'admin_state_up': pool.admin_state_up
         }
-        if pool.session_persistence:
-            peristence = pool.session_persistence
+        if pool.sessionpersistence:
+            peristence = pool.sessionpersistence
             peristence_payload = self.prepare_sessionpersistence(peristence)
-            update_attrs['session_persistence'] = peristence_payload
+            update_attrs['sessionpersistence'] = peristence_payload
         return update_attrs
 
     def prepare_sessionpersistence(self, persistence):
