@@ -13,15 +13,16 @@
 #    under the License.
 
 import copy
+import netaddr
 import threading
 import time
 
-import netaddr
-from neutron_lib import constants as n_constants
-from neutron_lib import context
-from neutron_lib.plugins import constants as pg_constants
+from neutron.api.v2 import attributes
+from neutron.common import log as call_log
+from neutron import context
+from neutron.i18n import _LE, _LW, _LI
+from neutron.plugins.common import constants
 from oslo_config import cfg
-from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 from oslo_utils import excutils
 from six.moves import queue as Queue
@@ -31,7 +32,7 @@ from neutron_lbaas.drivers.radware import base_v2_driver
 from neutron_lbaas.drivers.radware import exceptions as r_exc
 from neutron_lbaas.drivers.radware import rest_client as rest
 
-CERT_MANAGER_PLUGIN = neutron_lbaas.common.cert_manager.get_backend()
+CERT_MANAGER_PLUGIN = neutron_lbaas.common.cert_manager.CERT_MANAGER_PLUGIN
 TEMPLATE_HEADER = {'Content-Type':
                    'application/vnd.com.radware.vdirect.'
                    'template-parameters+json'}
@@ -52,17 +53,9 @@ PROPERTY_DEFAULTS = {'type': 'none',
                      'gw': '255.255.255.255',
                      }
 LOADBALANCER_PROPERTIES = ['vip_address', 'admin_state_up']
-LISTENER_PROPERTIES = ['id', 'protocol_port', 'protocol',
+LISTENER_PROPERTIES = ['protocol_port', 'protocol',
                        'connection_limit', 'admin_state_up']
-DEFAULT_CERT_PROPERTIES = ['id', 'certificate', 'intermediates',
-                           'private_key', 'passphrase']
-SNI_CERT_PROPERTIES = DEFAULT_CERT_PROPERTIES + ['position']
-L7_RULE_PROPERTIES = ['id', 'type', 'compare_type',
-                      'key', 'value', 'admin_state_up']
-L7_POLICY_PROPERTIES = ['id', 'action', 'redirect_pool_id',
-                        'redirect_url', 'position', 'admin_state_up']
-DEFAULT_POOL_PROPERTIES = ['id']
-POOL_PROPERTIES = ['id', 'protocol', 'lb_algorithm', 'admin_state_up']
+POOL_PROPERTIES = ['protocol', 'lb_algorithm', 'admin_state_up']
 MEMBER_PROPERTIES = ['id', 'address', 'protocol_port', 'weight',
                      'admin_state_up', 'subnet', 'mask', 'gw']
 SESSION_PERSISTENCY_PROPERTIES = ['type', 'cookie_name']
@@ -77,15 +70,15 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
     #
     # Assumptions:
     # 1) We have only one worflow that takes care of l2-l4 and service creation
-    # 2) The workflow template exists on the vDirect server
-    # 3) The workflow expose one operation named 'update' (plus ctor and dtor)
+    # 2) The workflow template exsists on the vDirect server
+    # 3) The workflow expose one operaion named 'update' (plus ctor and dtor)
     # 4) The 'update' operation gets the loadbalancer object graph as input
     # 5) The object graph is enehanced by our code before it is sent to the
     #    workflow
-    # 6) Async operations are handled by a different thread
+    # 6) Async operations are handled by a diffrent thread
     #
     def __init__(self, plugin):
-        base_v2_driver.RadwareLBaaSBaseV2Driver.__init__(self, plugin)
+        super(RadwareLBaaSV2Driver, self).__init__(plugin)
         rad = cfg.CONF.radwarev2
         rad_debug = cfg.CONF.radwarev2_debug
         self.plugin = plugin
@@ -131,17 +124,10 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
             server=vdirect_address,
             secondary_server=sec_server,
             user=rad.vdirect_user,
-            password=rad.vdirect_password,
-            port=rad.port,
-            ssl=rad.ssl,
-            ssl_verify_context=rad.ssl_verify_context,
-            timeout=rad.timeout,
-            base_uri=rad.base_uri)
+            password=rad.vdirect_password)
         self.workflow_params['provision_service'] = rad_debug.provision_service
         self.workflow_params['configure_l3'] = rad_debug.configure_l3
         self.workflow_params['configure_l4'] = rad_debug.configure_l4
-        self.configure_allowed_address_pairs =\
-            rad.configure_allowed_address_pairs
 
         self.queue = Queue.Queue()
         self.completion_handler = OperationCompletionHandler(self.queue,
@@ -153,7 +139,7 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
 
     def _start_completion_handling_thread(self):
         if not self.completion_handler_started:
-            LOG.info('Starting operation completion handling thread')
+            LOG.info(_LI('Starting operation completion handling thread'))
             self.completion_handler.start()
             self.completion_handler_started = True
 
@@ -161,7 +147,7 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
     def _get_wf_name(lb):
         return 'LB_' + lb.id
 
-    @log_helpers.log_method_call
+    @call_log.log
     def _verify_workflow_templates(self):
         """Verify the existence of workflows on vDirect server."""
         resource = '/api/workflowTemplate/'
@@ -182,7 +168,7 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
                 raise r_exc.WorkflowTemplateMissing(
                     workflow_template=template)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def workflow_exists(self, lb):
         """Create workflow for loadbalancer instance"""
         wf_name = self._get_wf_name(lb)
@@ -195,7 +181,7 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
             return False
         return True
 
-    @log_helpers.log_method_call
+    @call_log.log
     def _create_workflow(self, lb, lb_network_id, proxy_network_id):
         """Create workflow for loadbalancer instance"""
 
@@ -219,11 +205,10 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
         _rest_wrapper(self.rest_client.call(
             'POST', tmpl_resource,
             {'parameters': dict(self.workflow_params,
-                                service_params=service),
-            'tenants': [lb.tenant_id]},
+                                service_params=service)},
             TEMPLATE_HEADER))
 
-    @log_helpers.log_method_call
+    @call_log.log
     def get_stats(self, ctx, lb):
 
         wf_name = self._get_wf_name(lb)
@@ -239,7 +224,7 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
         LOG.debug('stats_values  response: %s ', response)
         return response['stats']
 
-    @log_helpers.log_method_call
+    @call_log.log
     def execute_workflow(self, ctx, manager, data_model,
                          old_data_model=None, delete=False):
         lb = data_model.root_loadbalancer
@@ -249,41 +234,32 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
         # is necessary.
         # Get subnet id of any member located on different than
         # loadbalancer's network. If returned subnet id is the subnet id
-        # of loadbalancer - all members are accessible from loadbalancer's
+        # of loadbalancer - all members are accesssible from loadbalancer's
         # network, meaning no second leg or static routes are required.
         # Otherwise, create proxy port on found member's subnet and get its
         # address as a proxy address for loadbalancer instance
         lb_subnet = self.plugin.db._core_plugin.get_subnet(
             ctx, lb.vip_subnet_id)
         proxy_subnet = lb_subnet
-        proxy_port_address = lb.vip_address
+        proxy_port_subnet_id = self._get_proxy_port_subnet_id(lb)
+        if proxy_port_subnet_id == lb.vip_subnet_id:
+            proxy_port_address = lb.vip_address
+        else:
+            proxy_port_address = self._create_proxy_port_and_get_address(
+                ctx, lb, proxy_port_subnet_id)
+            proxy_subnet = self.plugin.db._core_plugin.get_subnet(
+                ctx, proxy_port_subnet_id)
 
+        # Check if workflow exist, create if not
         if not self.workflow_exists(lb):
-            # Create proxy port if needed
-            proxy_port_subnet_id = self._get_proxy_port_subnet_id(lb)
-            if proxy_port_subnet_id != lb.vip_subnet_id:
-                proxy_port = self._create_proxy_port(
-                    ctx, lb, proxy_port_subnet_id)
-                proxy_subnet = self.plugin.db._core_plugin.get_subnet(
-                    ctx, proxy_port['subnet_id'])
-                proxy_port_address = proxy_port['ip_address']
-
             self._create_workflow(lb,
                                   lb_subnet['network_id'],
                                   proxy_subnet['network_id'])
-        else:
-            # Check if proxy port exists
-            proxy_port = self._get_proxy_port(ctx, lb)
-            if proxy_port:
-                proxy_subnet = self.plugin.db._core_plugin.get_subnet(
-                    ctx, proxy_port['subnet_id'])
-                proxy_port_address = proxy_port['ip_address']
 
         # Build objects graph
         objects_graph = self._build_objects_graph(ctx, lb, data_model,
                                                   proxy_port_address,
-                                                  proxy_subnet,
-                                                  delete)
+                                                  proxy_subnet)
         LOG.debug("Radware vDirect LB object graph is " + str(objects_graph))
 
         wf_name = self._get_wf_name(lb)
@@ -305,7 +281,7 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
 
     def remove_workflow(self, ctx, manager, lb):
         wf_name = self._get_wf_name(lb)
-        LOG.debug('Remove the workflow %s', wf_name)
+        LOG.debug('Remove the workflow %s' % wf_name)
         resource = '/api/workflow/%s' % (wf_name)
         rest_return = self.rest_client.call('DELETE', resource, None, None)
         response = _rest_wrapper(rest_return, [204, 202, 404])
@@ -315,167 +291,108 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
                 LOG.debug('Proxy port for LB %s was deleted', lb.id)
             except Exception:
                 with excutils.save_and_reraise_exception():
-                    LOG.error('Proxy port deletion for LB %s failed', lb.id)
-            manager.successful_completion(ctx, lb, delete=True)
+                    LOG.error(_LE('Proxy port deletion for LB %s '
+                                'failed'), lb.id)
+            manager.successful_completion(ctx, lb)
         else:
             oper = OperationAttributes(
                 manager, response['uri'], lb,
                 lb, old_data_model=None,
-                delete=True,
-                post_operation_function=self._delete_proxy_port)
+                delete=True)
 
             self._start_completion_handling_thread()
             self.queue.put_nowait(oper)
 
     def _build_objects_graph(self, ctx, lb, data_model,
-                             proxy_port_address, proxy_subnet,
-                             deleted):
+                             proxy_port_address, proxy_subnet):
         """Iterate over the LB model starting from root lb entity
         and build its JSON representtaion for vDirect
         """
-        deleted_ids = []
-        if deleted:
-            deleted_ids.append(data_model.id)
-
         graph = {}
         for prop in LOADBALANCER_PROPERTIES:
             graph[prop] = getattr(lb, prop, PROPERTY_DEFAULTS.get(prop))
 
         graph['pip_address'] = proxy_port_address
-        graph['configure_allowed_address_pairs'] =\
-            self.configure_allowed_address_pairs
 
         graph['listeners'] = []
-        listeners = [
-            listener for listener in lb.listeners
-            if listener.provisioning_status != n_constants.PENDING_DELETE and
-            (listener.default_pool and
-             listener.default_pool.provisioning_status !=
-             n_constants.PENDING_DELETE and
-             listener.default_pool.id not in deleted_ids and
-             listener.default_pool.members)]
-        for listener in listeners:
+        for listener in lb.listeners:
+            if not listener.default_pool or \
+                not listener.default_pool.members:
+                break
             listener_dict = {}
             for prop in LISTENER_PROPERTIES:
                 listener_dict[prop] = getattr(
                     listener, prop, PROPERTY_DEFAULTS.get(prop))
 
-            cert_mgr = CERT_MANAGER_PLUGIN.CertManager()
-
             if listener.default_tls_container_id:
-                default_cert = cert_mgr.get_cert(
-                    project_id=listener.tenant_id,
-                    cert_ref=listener.default_tls_container_id,
-                    resource_ref=cert_mgr.get_service_url(
-                        listener.loadbalancer_id),
+                default_cert = CERT_MANAGER_PLUGIN.CertManager.get_cert(
+                    listener.default_tls_container_id,
                     service_name='Neutron LBaaS v2 Radware provider')
-                def_cert_dict = {
-                    'id': listener.default_tls_container_id,
+                cert_dict = {
                     'certificate': default_cert.get_certificate(),
                     'intermediates': default_cert.get_intermediates(),
                     'private_key': default_cert.get_private_key(),
                     'passphrase': default_cert.get_private_key_passphrase()}
-                listener_dict['default_tls_certificate'] = def_cert_dict
+                listener_dict['default_tls_certificate'] = cert_dict
 
             if listener.sni_containers:
                 listener_dict['sni_tls_certificates'] = []
                 for sni_container in listener.sni_containers:
-                    sni_cert = cert_mgr.get_cert(
-                        project_id=listener.tenant_id,
-                        cert_ref=sni_container.tls_container_id,
-                        resource_ref=cert_mgr.get_service_url(
-                            listener.loadbalancer_id),
+                    sni_cert = CERT_MANAGER_PLUGIN.CertManager.get_cert(
+                        sni_container.tls_container_id,
                         service_name='Neutron LBaaS v2 Radware provider')
                     listener_dict['sni_tls_certificates'].append(
-                        {'id': sni_container.tls_container_id,
-                         'position': sni_container.position,
+                        {'position': sni_container.position,
                          'certificate': sni_cert.get_certificate(),
                          'intermediates': sni_cert.get_intermediates(),
                          'private_key': sni_cert.get_private_key(),
                          'passphrase': sni_cert.get_private_key_passphrase()})
 
-            listener_dict['l7_policies'] = []
-            policies = [
-                policy for policy in listener.l7_policies
-                if policy.provisioning_status != n_constants.PENDING_DELETE and
-                policy.id not in deleted_ids]
-            for policy in policies:
-                policy_dict = {}
-                for prop in L7_POLICY_PROPERTIES:
-                    policy_dict[prop] = getattr(
-                        policy, prop, PROPERTY_DEFAULTS.get(prop))
-                policy_dict['rules'] = []
-                rules = [
-                    rule for rule in policy.rules
-                    if rule.provisioning_status != n_constants.PENDING_DELETE
-                    and rule.id not in deleted_ids]
-                for rule in rules:
-                    rule_dict = {}
-                    for prop in L7_RULE_PROPERTIES:
-                        rule_dict[prop] = getattr(
-                            rule, prop, PROPERTY_DEFAULTS.get(prop))
-                    policy_dict['rules'].append(rule_dict)
-                if policy_dict['rules']:
-                    listener_dict['l7_policies'].append(policy_dict)
-
-            def_pool_dict = {'id': listener.default_pool.id}
-
-            if listener.default_pool.session_persistence:
-                sess_pers_dict = {}
-                for prop in SESSION_PERSISTENCY_PROPERTIES:
-                    sess_pers_dict[prop] = getattr(
-                        listener.default_pool.session_persistence, prop,
+            if listener.default_pool:
+                pool_dict = {}
+                for prop in POOL_PROPERTIES:
+                    pool_dict[prop] = getattr(
+                        listener.default_pool, prop,
                         PROPERTY_DEFAULTS.get(prop))
-                def_pool_dict['sessionpersistence'] = sess_pers_dict
-            listener_dict['default_pool'] = def_pool_dict
 
+                if listener.default_pool.healthmonitor:
+                    hm_dict = {}
+                    for prop in HEALTH_MONITOR_PROPERTIES:
+                        hm_dict[prop] = getattr(
+                            listener.default_pool.healthmonitor, prop,
+                            PROPERTY_DEFAULTS.get(prop))
+                    pool_dict['healthmonitor'] = hm_dict
+
+                if listener.default_pool.sessionpersistence:
+                    sess_pers_dict = {}
+                    for prop in SESSION_PERSISTENCY_PROPERTIES:
+                        sess_pers_dict[prop] = getattr(
+                            listener.default_pool.sessionpersistence, prop,
+                            PROPERTY_DEFAULTS.get(prop))
+                    pool_dict['sessionpersistence'] = sess_pers_dict
+
+                pool_dict['members'] = []
+                for member in listener.default_pool.members:
+                    member_dict = {}
+                    for prop in MEMBER_PROPERTIES:
+                        member_dict[prop] = getattr(
+                            member, prop,
+                            PROPERTY_DEFAULTS.get(prop))
+                    if (proxy_port_address != lb.vip_address and
+                        netaddr.IPAddress(member.address)
+                        not in netaddr.IPNetwork(proxy_subnet['cidr'])):
+                        self._accomplish_member_static_route_data(
+                            ctx, member, member_dict,
+                            proxy_subnet['gateway_ip'])
+                    pool_dict['members'].append(member_dict)
+
+                listener_dict['default_pool'] = pool_dict
             graph['listeners'].append(listener_dict)
-
-        graph['pools'] = []
-        pools = [
-            pool for pool in lb.pools
-            if pool.provisioning_status != n_constants.PENDING_DELETE and
-            pool.id not in deleted_ids]
-        for pool in pools:
-            pool_dict = {}
-            for prop in POOL_PROPERTIES:
-                pool_dict[prop] = getattr(
-                    pool, prop,
-                    PROPERTY_DEFAULTS.get(prop))
-
-            if (pool.healthmonitor and
-                pool.healthmonitor.provisioning_status !=
-                n_constants.PENDING_DELETE and
-                pool.healthmonitor.id not in deleted_ids):
-                hm_dict = {}
-                for prop in HEALTH_MONITOR_PROPERTIES:
-                    hm_dict[prop] = getattr(
-                        pool.healthmonitor, prop,
-                        PROPERTY_DEFAULTS.get(prop))
-                pool_dict['healthmonitor'] = hm_dict
-
-            pool_dict['members'] = []
-            members = [
-                member for member in pool.members
-                if member.provisioning_status != n_constants.PENDING_DELETE and
-                member.id not in deleted_ids]
-            for member in members:
-                member_dict = {}
-                for prop in MEMBER_PROPERTIES:
-                    member_dict[prop] = getattr(
-                        member, prop,
-                        PROPERTY_DEFAULTS.get(prop))
-                if (proxy_port_address != lb.vip_address and
-                    netaddr.IPAddress(member.address)
-                    not in netaddr.IPNetwork(proxy_subnet['cidr'])):
-                    self._accomplish_member_static_route_data(
-                        ctx, member, member_dict,
-                        proxy_subnet['gateway_ip'])
-                pool_dict['members'].append(member_dict)
-            graph['pools'].append(pool_dict)
-
         return graph
 
+    def _get_lb_proxy_port_name(self, lb):
+        return 'proxy_' + lb.id
+
     def _get_proxy_port_subnet_id(self, lb):
         """Look for at least one member of any listener's pool
         that is located on subnet different than loabalancer's subnet.
@@ -489,76 +406,61 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
                         return member.subnet_id
         return lb.vip_subnet_id
 
-    def _create_proxy_port(self,
+    def _create_proxy_port_and_get_address(self,
         ctx, lb, proxy_port_subnet_id):
         """Check if proxy port was created earlier.
         If not, create a new port on proxy subnet and return its ip address.
         Returns port IP address
         """
-        proxy_port = self._get_proxy_port(ctx, lb)
-        if proxy_port:
-            LOG.info('LB %(lb_id)s proxy port exists on subnet '
-                     '%(subnet_id)s with ip address %(ip_address)s' %
-                     {'lb_id': lb.id, 'subnet_id': proxy_port['subnet_id'],
-                      'ip_address': proxy_port['ip_address']})
-            return proxy_port
-
-        proxy_port_name = 'proxy_' + lb.id
-        proxy_port_subnet = self.plugin.db._core_plugin.get_subnet(
-            ctx, proxy_port_subnet_id)
-        proxy_port_data = {
-            'tenant_id': lb.tenant_id,
-            'name': proxy_port_name,
-            'network_id': proxy_port_subnet['network_id'],
-            'mac_address': n_constants.ATTR_NOT_SPECIFIED,
-            'admin_state_up': False,
-            'device_id': '',
-            'device_owner': 'neutron:' + pg_constants.LOADBALANCERV2,
-            'fixed_ips': [{'subnet_id': proxy_port_subnet_id}]
-        }
-        proxy_port = self.plugin.db._core_plugin.create_port(
-            ctx, {'port': proxy_port_data})
-        proxy_port_ip_data = proxy_port['fixed_ips'][0]
-
-        LOG.info('LB %(lb_id)s proxy port created on subnet %(subnet_id)s '
-                 'with ip address %(ip_address)s' %
-                 {'lb_id': lb.id, 'subnet_id': proxy_port_ip_data['subnet_id'],
-                  'ip_address': proxy_port_ip_data['ip_address']})
-
-        return proxy_port_ip_data
-
-    def _get_proxy_port(self, ctx, lb):
+        proxy_port_name = self._get_lb_proxy_port_name(lb)
         ports = self.plugin.db._core_plugin.get_ports(
-            ctx, filters={'name': ['proxy_' + lb.id], })
+            ctx, filters={'name': [proxy_port_name], })
         if not ports:
-            return None
+            # Create pip port. Use the subnet
+            # determined before by _get_pip_port_subnet_id() function
+            proxy_port_subnet = self.plugin.db._core_plugin.get_subnet(
+                ctx, proxy_port_subnet_id)
+            proxy_port_data = {
+                'tenant_id': lb.tenant_id,
+                'name': proxy_port_name,
+                'network_id': proxy_port_subnet['network_id'],
+                'mac_address': attributes.ATTR_NOT_SPECIFIED,
+                'admin_state_up': False,
+                'device_id': '',
+                'device_owner': 'neutron:' + constants.LOADBALANCERV2,
+                'fixed_ips': [{'subnet_id': proxy_port_subnet_id}]
+            }
+            proxy_port = self.plugin.db._core_plugin.create_port(
+                ctx, {'port': proxy_port_data})
+        else:
+            proxy_port = ports[0]
 
-        proxy_port = ports[0]
-        return proxy_port['fixed_ips'][0]
+        ips_on_subnet = [ip for ip in proxy_port['fixed_ips']
+                         if ip['subnet_id'] == proxy_port_subnet_id]
+        if not ips_on_subnet:
+            raise Exception(_('Could not find or allocate '
+                              'IP address on subnet id %s for proxy port'),
+                            proxy_port_subnet_id)
+        else:
+            return ips_on_subnet[0]['ip_address']
 
     def _delete_proxy_port(self, ctx, lb):
         port_filter = {
-            'name': ['proxy_' + lb.id],
+            'name': [self._get_lb_proxy_port_name(lb)],
         }
         ports = self.plugin.db._core_plugin.get_ports(
             ctx, filters=port_filter)
         if ports:
-            proxy_port = ports[0]
-            proxy_port_ip_data = proxy_port['fixed_ips'][0]
-            try:
-                LOG.info('Deleting LB %(lb_id)s proxy port on subnet  '
-                         '%(subnet_id)s with ip address %(ip_address)s' %
-                         {'lb_id': lb.id,
-                          'subnet_id': proxy_port_ip_data['subnet_id'],
-                          'ip_address': proxy_port_ip_data['ip_address']})
-                self.plugin.db._core_plugin.delete_port(
-                    ctx, proxy_port['id'])
+            for port in ports:
+                try:
+                    self.plugin.db._core_plugin.delete_port(
+                        ctx, port['id'])
 
-            except Exception as exception:
-                # stop exception propagation, nport may have
-                # been deleted by other means
-                LOG.warning('Proxy port deletion failed: %r',
-                            exception)
+                except Exception as exception:
+                    # stop exception propagation, nport may have
+                    # been deleted by other means
+                    LOG.warning(_LW('proxy port deletion failed: %r'),
+                                exception)
 
     def _accomplish_member_static_route_data(self,
         ctx, member, member_data, proxy_gateway_ip):
@@ -567,13 +469,9 @@ class RadwareLBaaSV2Driver(base_v2_driver.RadwareLBaaSBaseV2Driver):
             filters={'fixed_ips': {'ip_address': [member.address]},
                      'tenant_id': [member.tenant_id]})
         if len(member_ports) == 1:
-            member_port = member_ports[0]
-            member_port_ip_data = member_port['fixed_ips'][0]
-            LOG.debug('member_port_ip_data:' + repr(member_port_ip_data))
-            member_subnet = self.plugin.db._core_plugin.get_subnet(
+            member_subnet = self.plugin._core_plugin.get_subnet(
                 ctx,
-                member_port_ip_data['subnet_id'])
-            LOG.debug('member_subnet:' + repr(member_subnet))
+                member_ports[0]['fixed_ips'][0]['subnet_id'])
             member_network = netaddr.IPNetwork(member_subnet['cidr'])
             member_data['subnet'] = str(member_network.network)
             member_data['mask'] = str(member_network.netmask)
@@ -603,7 +501,7 @@ class OperationCompletionHandler(threading.Thread):
                                        oper.operation_url,
                                        None,
                                        None)
-        LOG.debug('Operation completion requested %(uri)s and got: %(result)s',
+        LOG.debug('Operation completion requested %(uri) and got: %(result)',
                   {'uri': oper.operation_url, 'result': result})
         completed = result[rest.RESP_DATA]['complete']
         reason = result[rest.RESP_REASON],
@@ -627,13 +525,13 @@ class OperationCompletionHandler(threading.Thread):
                 else:
                     msg = "unknown"
                 error_params = {"operation": oper, "msg": msg}
-                LOG.error(
-                    'Operation %(operation)s failed. Reason: %(msg)s',
+                LOG.error(_LE(
+                    'Operation %(operation)s failed. Reason: %(msg)s'),
                     error_params)
-                oper.status = n_constants.ERROR
+                oper.status = constants.ERROR
                 OperationCompletionHandler._run_post_failure_function(oper)
             else:
-                oper.status = n_constants.ACTIVE
+                oper.status = constants.ACTIVE
                 OperationCompletionHandler._run_post_success_function(oper)
 
         return completed
@@ -669,15 +567,13 @@ class OperationCompletionHandler(threading.Thread):
             except Queue.Empty:
                 continue
             except Exception:
-                LOG.error(
-                    "Exception was thrown inside OperationCompletionHandler")
+                LOG.error(_LE(
+                    "Exception was thrown inside OperationCompletionHandler"))
 
     @staticmethod
     def _run_post_success_function(oper):
         try:
-            ctx = context.get_admin_context()
-            if oper.post_operation_function:
-                oper.post_operation_function(ctx, oper.data_model)
+            ctx = context.get_admin_context(load_admin_roles=False)
             oper.manager.successful_completion(ctx, oper.data_model,
                                                delete=oper.delete)
             LOG.debug('Post-operation success function completed '
@@ -685,22 +581,22 @@ class OperationCompletionHandler(threading.Thread):
                       repr(oper))
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.error('Post-operation success function failed '
-                          'for operation %s',
+                LOG.error(_LE('Post-operation success function failed '
+                             'for operation %s'),
                           repr(oper))
 
     @staticmethod
     def _run_post_failure_function(oper):
         try:
-            ctx = context.get_admin_context()
+            ctx = context.get_admin_context(load_admin_roles=False)
             oper.manager.failed_completion(ctx, oper.data_model)
             LOG.debug('Post-operation failure function completed '
                       'for operation %s',
                       repr(oper))
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.error('Post-operation failure function failed '
-                          'for operation %s',
+                LOG.error(_LE('Post-operation failure function failed '
+                              'for operation %s'),
                           repr(oper))
 
 
@@ -714,15 +610,13 @@ class OperationAttributes(object):
                  lb,
                  data_model=None,
                  old_data_model=None,
-                 delete=False,
-                 post_operation_function=None):
+                 delete=False):
         self.manager = manager
         self.operation_url = operation_url
         self.lb = lb
         self.data_model = data_model
         self.old_data_model = old_data_model
         self.delete = delete
-        self.post_operation_function = post_operation_function
         self.creation_time = time.time()
 
     def __repr__(self):
