@@ -17,22 +17,19 @@ import contextlib
 
 import mock
 from neutron.api import extensions
-from neutron.callbacks import events
-from neutron.callbacks import registry
-from neutron.callbacks import resources
 from neutron.common import config
+from neutron.common import constants as n_constants
+from neutron.common import exceptions as n_exc
 from neutron import context
 from neutron.db import servicetype_db as sdb
 from neutron import manager
 from neutron.plugins.common import constants
 from neutron.services import provider_configuration as pconf
 from neutron.tests.unit.db import test_db_base_plugin_v2
-from neutron_lib import constants as n_constants
-from neutron_lib import exceptions as n_exc
+from oslo_config import cfg
 import testtools
 import webob.exc
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.db.loadbalancer import loadbalancer_db as ldb
 import neutron_lbaas.extensions
 from neutron_lbaas.extensions import loadbalancer
@@ -113,7 +110,7 @@ class NoopLbaaSDriver(abstract_driver.LoadBalancerAbstractDriver):
 
 class LoadBalancerTestMixin(object):
     resource_prefix_map = dict(
-        (k, loadbalancer.LOADBALANCER_PREFIX)
+        (k, constants.COMMON_PREFIXES[constants.LOADBALANCER])
         for k in loadbalancer.RESOURCE_ATTRIBUTE_MAP.keys()
     )
 
@@ -137,14 +134,14 @@ class LoadBalancerTestMixin(object):
         vip_req = self.new_create_request('vips', data, fmt)
         vip_res = vip_req.get_response(self.ext_api)
         if expected_res_status:
-            self.assertEqual(expected_res_status, vip_res.status_int)
+            self.assertEqual(vip_res.status_int, expected_res_status)
 
         return vip_res
 
     def _create_pool(self, fmt, name, lb_method, protocol, admin_state_up,
-                     subnet_id, expected_res_status=None, **kwargs):
+                     expected_res_status=None, **kwargs):
         data = {'pool': {'name': name,
-                         'subnet_id': subnet_id,
+                         'subnet_id': _subnet_id,
                          'lb_method': lb_method,
                          'protocol': protocol,
                          'admin_state_up': admin_state_up,
@@ -155,7 +152,7 @@ class LoadBalancerTestMixin(object):
         pool_req = self.new_create_request('pools', data, fmt)
         pool_res = pool_req.get_response(self.ext_api)
         if expected_res_status:
-            self.assertEqual(expected_res_status, pool_res.status_int)
+            self.assertEqual(pool_res.status_int, expected_res_status)
 
         return pool_res
 
@@ -172,7 +169,7 @@ class LoadBalancerTestMixin(object):
         member_req = self.new_create_request('members', data, fmt)
         member_res = member_req.get_response(self.ext_api)
         if expected_res_status:
-            self.assertEqual(expected_res_status, member_res.status_int)
+            self.assertEqual(member_res.status_int, expected_res_status)
 
         return member_res
 
@@ -193,7 +190,7 @@ class LoadBalancerTestMixin(object):
 
         res = req.get_response(self.ext_api)
         if expected_res_status:
-            self.assertEqual(expected_res_status, res.status_int)
+            self.assertEqual(res.status_int, expected_res_status)
 
         return res
 
@@ -231,16 +228,14 @@ class LoadBalancerTestMixin(object):
     @contextlib.contextmanager
     def pool(self, fmt=None, name='pool1', lb_method='ROUND_ROBIN',
              protocol='HTTP', admin_state_up=True, do_delete=True,
-             subnet_id=None, **kwargs):
+             **kwargs):
         if not fmt:
             fmt = self.fmt
-        subnet_id = subnet_id or _subnet_id
         res = self._create_pool(fmt,
                                 name,
                                 lb_method,
                                 protocol,
                                 admin_state_up,
-                                subnet_id,
                                 **kwargs)
         if res.status_int >= webob.exc.HTTPClientError.code:
             raise webob.exc.HTTPClientError(
@@ -316,9 +311,11 @@ class LoadBalancerPluginDbTestCase(LoadBalancerTestMixin,
             lbaas_provider = (
                 constants.LOADBALANCER +
                 ':lbaas:' + NOOP_DRIVER_KLASS + ':default')
-
-        # override the default service provider
-        self.set_override([lbaas_provider])
+        cfg.CONF.set_override('service_provider',
+                              [lbaas_provider],
+                              'service_providers')
+        #force service type manager to reload configuration:
+        sdb.ServiceTypeManager._instance = None
 
         # removing service-type because it resides in neutron and tests
         # dont care
@@ -377,9 +374,9 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     self.assertTrue(vip['vip'].get(k, None))
 
                 self.assertEqual(
-                    expected,
                     dict((k, v)
-                         for k, v in vip['vip'].items() if k in expected)
+                         for k, v in vip['vip'].items() if k in expected),
+                    expected
                 )
             return vip
 
@@ -470,7 +467,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     # check that pool1.vip became None
                     self.assertIsNone(db_pool1.vip)
                     # and pool2 got vip
-                    self.assertEqual(vip['vip']['id'], db_pool2.vip.id)
+                    self.assertEqual(db_pool2.vip.id, vip['vip']['id'])
 
     def test_create_vip_with_invalid_values(self):
         invalid = {
@@ -529,8 +526,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 data = {'vip': {'pool_id': pool['pool']['id']}}
                 req = self.new_update_request('vips', data, vip['vip']['id'])
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPClientError.code,
-                                 res.status_int)
+                self.assertEqual(res.status_int,
+                                 webob.exc.HTTPClientError.code)
 
     def test_reset_session_persistence(self):
         name = 'vip4'
@@ -540,8 +537,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
 
         with self.vip(name=name, session_persistence=session_persistence) as v:
             # Ensure that vip has been created properly
-            self.assertEqual(session_persistence,
-                             v['vip']['session_persistence'])
+            self.assertEqual(v['vip']['session_persistence'],
+                             session_persistence)
 
             # Try resetting session_persistence
             req = self.new_update_request('vips', update_info, v['vip']['id'])
@@ -569,7 +566,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             req = self.new_update_request('vips', data, vip['vip']['id'])
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
             for k, v in keys:
-                self.assertEqual(v, res['vip'][k])
+                self.assertEqual(res['vip'][k], v)
 
     def test_delete_vip(self):
         with self.pool():
@@ -577,7 +574,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 req = self.new_delete_request('vips',
                                               vip['vip']['id'])
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPNoContent.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPNoContent.code)
 
     def test_show_vip(self):
         name = "vip_show"
@@ -593,7 +590,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                         vip['vip']['id'])
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
             for k, v in keys:
-                self.assertEqual(v, res['vip'][k])
+                self.assertEqual(res['vip'][k], v)
 
     def test_list_vips(self):
         name = "vips_list"
@@ -608,9 +605,9 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             keys.append(('subnet_id', vip['vip']['subnet_id']))
             req = self.new_list_request('vips')
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
-            self.assertEqual(1, len(res['vips']))
+            self.assertEqual(len(res['vips']), 1)
             for k, v in keys:
-                self.assertEqual(v, res['vips'][0][k])
+                self.assertEqual(res['vips'][0][k], v)
 
     def test_list_vips_with_sort_emulated(self):
         with self.subnet() as subnet:
@@ -662,9 +659,10 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                  ':haproxy:neutron_lbaas.services.loadbalancer.'
                  'drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver'
                  ':default')
-        # override the default service provider
-        self.set_override([prov1, prov2])
-
+        cfg.CONF.set_override('service_provider',
+                              [prov1, prov2],
+                              'service_providers')
+        sdb.ServiceTypeManager._instance = None
         self.plugin = loadbalancer_plugin.LoadBalancerPlugin()
         with self.subnet() as subnet:
             ctx = context.get_admin_context()
@@ -680,8 +678,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     'description': ''}
             self.plugin.create_pool(ctx, {'pool': pool})
             assoc = ctx.session.query(sdb.ProviderResourceAssociation).one()
-            self.assertEqual(pconf.normalize_provider_name(provider_name),
-                             assoc.provider_name)
+            self.assertEqual(assoc.provider_name,
+                             pconf.normalize_provider_name(provider_name))
 
     def test_create_pool_another_provider(self):
         self._create_pool_directly_via_plugin('lbaas')
@@ -706,7 +704,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
 
         with self.pool(name=name) as pool:
             for k, v in keys:
-                self.assertEqual(v, pool['pool'][k])
+                self.assertEqual(pool['pool'][k], v)
 
     def test_create_pool_with_members(self):
         name = "pool2"
@@ -729,7 +727,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             member1 = self.deserialize(self.fmt, res1)
             self.assertEqual(member1['member']['id'],
                              pool_updated['pool']['members'][0])
-            self.assertEqual(1, len(pool_updated['pool']['members']))
+            self.assertEqual(len(pool_updated['pool']['members']), 1)
 
             keys = [('address', '192.168.1.100'),
                     ('protocol_port', 80),
@@ -738,7 +736,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     ('admin_state_up', True),
                     ('status', 'PENDING_CREATE')]
             for k, v in keys:
-                self.assertEqual(v, member1['member'][k])
+                self.assertEqual(member1['member'][k], v)
             self._delete('members', member1['member']['id'])
 
     def test_delete_pool(self):
@@ -748,7 +746,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 req = self.new_delete_request('pools',
                                               pool['pool']['id'])
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPNoContent.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPNoContent.code)
 
     def test_delete_pool_preserve_state(self):
         with self.pool(do_delete=False) as pool:
@@ -756,38 +754,19 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 req = self.new_delete_request('pools',
                                               pool['pool']['id'])
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPConflict.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPConflict.code)
                 req = self.new_show_request('pools',
                                             pool['pool']['id'],
                                             fmt=self.fmt)
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPOk.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPOk.code)
                 res = self.deserialize(self.fmt,
                                        req.get_response(self.ext_api))
-                self.assertEqual(constants.PENDING_CREATE,
-                                 res['pool']['status'])
+                self.assertEqual(res['pool']['status'],
+                                 constants.PENDING_CREATE)
             req = self.new_delete_request('pools',
                                           pool['pool']['id'])
 
-    def test_delete_subnet_with_pool(self):
-        registry.subscribe(ldb.is_subnet_in_use_callback,
-                           resources.SUBNET, events.BEFORE_DELETE)
-
-        try:
-            with self.subnet() as subnet:
-                with self.pool(subnet_id=subnet['subnet']['id']):
-                    req = self.new_delete_request('subnets',
-                                                  subnet['subnet']['id'])
-                    res = req.get_response(self.api)
-
-                    self.assertIn('NeutronError', res.json)
-                    self.assertEqual('SubnetInUse',
-                                     res.json['NeutronError']['type'])
-                    self.assertEqual(409, res.status_code)
-        finally:
-            registry.unsubscribe(ldb.is_subnet_in_use_callback,
-                                 resources.SUBNET, events.BEFORE_DELETE)
-
     def test_show_pool(self):
         name = "pool1"
         keys = [('name', name),
@@ -803,7 +782,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                         fmt=self.fmt)
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
             for k, v in keys:
-                self.assertEqual(v, res['pool'][k])
+                self.assertEqual(res['pool'][k], v)
 
     def test_list_pools_with_sort_emulated(self):
         with contextlib.nested(self.pool(name='p1'),
@@ -864,8 +843,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         'protocol_port': 80,
                         'weight': 1,
                         'admin_state_up': True,
-                        'pool_id': pool_id,
-                        'tenant_id': self._tenant_id
+                        'pool_id': pool_id
                     }
                     self.assertRaises(loadbalancer.MemberExists,
                                       self.plugin.create_member,
@@ -890,7 +868,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         self.fmt,
                         req.get_response(self.ext_api)
                     )
-                    self.assertEqual(1, len(pool1_update['pool']['members']))
+                    self.assertEqual(len(pool1_update['pool']['members']), 1)
 
                     req = self.new_show_request('pools',
                                                 pool2['pool']['id'],
@@ -899,8 +877,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         self.fmt,
                         req.get_response(self.ext_api)
                     )
-                    self.assertEqual(1, len(pool1_update['pool']['members']))
-                    self.assertEqual(0, len(pool2_update['pool']['members']))
+                    self.assertEqual(len(pool1_update['pool']['members']), 1)
+                    self.assertEqual(len(pool2_update['pool']['members']), 0)
 
                     data = {'member': {'pool_id': pool2['pool']['id'],
                                        'weight': 10,
@@ -913,7 +891,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         req.get_response(self.ext_api)
                     )
                     for k, v in keys:
-                        self.assertEqual(v, res['member'][k])
+                        self.assertEqual(res['member'][k], v)
 
                     req = self.new_show_request('pools',
                                                 pool1['pool']['id'],
@@ -931,8 +909,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         req.get_response(self.ext_api)
                     )
 
-                    self.assertEqual(1, len(pool2_update['pool']['members']))
-                    self.assertEqual(0, len(pool1_update['pool']['members']))
+                    self.assertEqual(len(pool2_update['pool']['members']), 1)
+                    self.assertEqual(len(pool1_update['pool']['members']), 0)
 
     def test_delete_member(self):
         with self.pool() as pool:
@@ -942,7 +920,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 req = self.new_delete_request('members',
                                               member['member']['id'])
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPNoContent.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPNoContent.code)
 
                 req = self.new_show_request('pools',
                                             pool_id,
@@ -951,7 +929,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     self.fmt,
                     req.get_response(self.ext_api)
                 )
-                self.assertEqual(0, len(pool_update['pool']['members']))
+                self.assertEqual(len(pool_update['pool']['members']), 0)
 
     def test_show_member(self):
         with self.pool() as pool:
@@ -971,7 +949,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     req.get_response(self.ext_api)
                 )
                 for k, v in keys:
-                    self.assertEqual(v, res['member'][k])
+                    self.assertEqual(res['member'][k], v)
 
     def test_list_members_with_sort_emulated(self):
         with self.pool() as pool:
@@ -1020,7 +998,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 ('admin_state_up', True)]
         with self.health_monitor() as monitor:
             for k, v in keys:
-                self.assertEqual(v, monitor['health_monitor'][k])
+                self.assertEqual(monitor['health_monitor'][k], v)
 
     def test_create_health_monitor_with_timeout_delay_invalid(self):
         data = {'health_monitor': {'type': type,
@@ -1062,7 +1040,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                           monitor['health_monitor']['id'])
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
             for k, v in keys:
-                self.assertEqual(v, res['health_monitor'][k])
+                self.assertEqual(res['health_monitor'][k], v)
 
     def test_delete_healthmonitor(self):
         with self.health_monitor(do_delete=False) as monitor:
@@ -1074,7 +1052,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             req = self.new_delete_request('health_monitors',
                                           monitor['health_monitor']['id'])
             res = req.get_response(self.ext_api)
-            self.assertEqual(webob.exc.HTTPNoContent.code, res.status_int)
+            self.assertEqual(res.status_int, webob.exc.HTTPNoContent.code)
             qry = ctx.session.query(ldb.HealthMonitor)
             qry = qry.filter_by(id=monitor['health_monitor']['id'])
             self.assertIsNone(qry.first())
@@ -1095,7 +1073,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     id=pool['pool']['id'],
                     subresource='health_monitors')
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPCreated.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPCreated.code)
 
                 ctx = context.get_admin_context()
 
@@ -1109,7 +1087,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     monitor['health_monitor']['id']
                 )
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPConflict.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPConflict.code)
 
                 qry = ctx.session.query(ldb.HealthMonitor)
                 qry = qry.filter_by(id=monitor['health_monitor']['id'])
@@ -1132,7 +1110,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                         fmt=self.fmt)
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
             for k, v in keys:
-                self.assertEqual(v, res['health_monitor'][k])
+                self.assertEqual(res['health_monitor'][k], v)
 
     def test_list_healthmonitors_with_sort_emulated(self):
         with contextlib.nested(self.health_monitor(delay=30),
@@ -1178,7 +1156,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             self.plugin.update_pool_stats(ctx, pool_id)
             pool_obj = ctx.session.query(ldb.Pool).filter_by(id=pool_id).one()
             for key in keys:
-                self.assertEqual(0, pool_obj.stats.__dict__[key])
+                self.assertEqual(pool_obj.stats.__dict__[key], 0)
 
     def test_update_pool_stats_with_negative_values(self):
         stats_data = {"bytes_in": -1,
@@ -1206,7 +1184,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             self.plugin.update_pool_stats(ctx, pool_id, stats_data)
             pool_obj = ctx.session.query(ldb.Pool).filter_by(id=pool_id).one()
             for k, v in stats_data.items():
-                self.assertEqual(v, pool_obj.stats.__dict__[k])
+                self.assertEqual(pool_obj.stats.__dict__[k], v)
 
     def test_update_pool_stats_members_statuses(self):
         with self.pool() as pool:
@@ -1237,7 +1215,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                         fmt=self.fmt)
             res = self.deserialize(self.fmt, req.get_response(self.ext_api))
             for k, v in keys:
-                self.assertEqual(v, res['stats'][k])
+                self.assertEqual(res['stats'][k], v)
 
     def test_create_healthmonitor_of_pool(self):
         with self.health_monitor(type="TCP") as monitor1:
@@ -1253,8 +1231,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         id=pool['pool']['id'],
                         subresource="health_monitors")
                     res = req.get_response(self.ext_api)
-                    self.assertEqual(webob.exc.HTTPCreated.code,
-                                     res.status_int)
+                    self.assertEqual(res.status_int,
+                                     webob.exc.HTTPCreated.code)
 
                     data = {"health_monitor": {
                             "id": monitor2['health_monitor']['id'],
@@ -1266,8 +1244,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         id=pool['pool']['id'],
                         subresource="health_monitors")
                     res = req.get_response(self.ext_api)
-                    self.assertEqual(webob.exc.HTTPCreated.code,
-                                     res.status_int)
+                    self.assertEqual(res.status_int,
+                                     webob.exc.HTTPCreated.code)
 
                     req = self.new_show_request(
                         'pools',
@@ -1307,8 +1285,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         id=pool['pool']['id'],
                         subresource="health_monitors")
                     res = req.get_response(self.ext_api)
-                    self.assertEqual(webob.exc.HTTPCreated.code,
-                                     res.status_int)
+                    self.assertEqual(res.status_int,
+                                     webob.exc.HTTPCreated.code)
 
                     data = {"health_monitor": {
                             "id": monitor2['health_monitor']['id'],
@@ -1320,8 +1298,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         id=pool['pool']['id'],
                         subresource="health_monitors")
                     res = req.get_response(self.ext_api)
-                    self.assertEqual(webob.exc.HTTPCreated.code,
-                                     res.status_int)
+                    self.assertEqual(res.status_int,
+                                     webob.exc.HTTPCreated.code)
 
                     # remove one of healthmonitor from the pool
                     req = self.new_delete_request(
@@ -1331,8 +1309,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                         sub_id=monitor1['health_monitor']['id'],
                         subresource="health_monitors")
                     res = req.get_response(self.ext_api)
-                    self.assertEqual(webob.exc.HTTPNoContent.code,
-                                     res.status_int)
+                    self.assertEqual(res.status_int,
+                                     webob.exc.HTTPNoContent.code)
 
                     req = self.new_show_request(
                         'pools',
@@ -1383,7 +1361,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                                   '3',
                                                   True)
                 health_monitor = self.deserialize(self.fmt, req)
-                self.assertEqual(webob.exc.HTTPCreated.code, req.status_int)
+                self.assertEqual(req.status_int, webob.exc.HTTPCreated.code)
 
                 # Associate the health_monitor to the pool
                 data = {"health_monitor": {
@@ -1395,7 +1373,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                                               id=pool['pool']['id'],
                                               subresource="health_monitors")
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPCreated.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPCreated.code)
 
                 # Get pool and vip
                 req = self.new_show_request('pools',
@@ -1428,8 +1406,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     self.fmt,
                     req.get_response(self.ext_api)
                 )
-                self.assertEqual(pool_updated['pool']['id'],
-                                 vip_updated['vip']['pool_id'])
+                self.assertEqual(vip_updated['vip']['pool_id'],
+                                 pool_updated['pool']['id'])
 
                 # clean up
                 # disassociate the health_monitor from the pool first
@@ -1440,7 +1418,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                     subresource="health_monitors",
                     sub_id=health_monitor['health_monitor']['id'])
                 res = req.get_response(self.ext_api)
-                self.assertEqual(webob.exc.HTTPNoContent.code, res.status_int)
+                self.assertEqual(res.status_int, webob.exc.HTTPNoContent.code)
                 self._delete('health_monitors',
                              health_monitor['health_monitor']['id'])
                 self._delete('members', member1['member']['id'])
@@ -1472,8 +1450,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 res = self.plugin.get_pool_health_monitor(
                     context.get_admin_context(),
                     health_mon2['health_monitor']['id'], pool['pool']['id'])
-                self.assertEqual(health_mon1['health_monitor']['tenant_id'],
-                                 res['tenant_id'])
+                self.assertEqual(res['tenant_id'],
+                                 health_mon1['health_monitor']['tenant_id'])
 
     def test_driver_call_create_pool_health_monitor(self):
         with mock.patch.object(self.plugin.drivers['lbaas'],
@@ -1518,8 +1496,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                          {'pool_id': p2['pool']['id'],
                           'status': 'PENDING_CREATE',
                           'status_description': None}]
-            self.assertEqual(sorted(pool_data),
-                             sorted(healthmon['pools']))
+            self.assertEqual(sorted(healthmon['pools']),
+                             sorted(pool_data))
             req = self.new_show_request(
                 'health_monitors',
                 hm['health_monitor']['id'],
@@ -1528,8 +1506,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 self.fmt,
                 req.get_response(self.ext_api)
             )
-            self.assertEqual(sorted(pool_data),
-                             sorted(hm['health_monitor']['pools']))
+            self.assertEqual(sorted(hm['health_monitor']['pools']),
+                             sorted(pool_data))
 
     def test_create_pool_health_monitor_already_associated(self):
         with contextlib.nested(
@@ -1570,22 +1548,22 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
 
     def test_update_status(self):
         with self.pool() as pool:
-            self.assertEqual('PENDING_CREATE', pool['pool']['status'])
+            self.assertEqual(pool['pool']['status'], 'PENDING_CREATE')
             self.assertFalse(pool['pool']['status_description'])
 
             self.plugin.update_status(context.get_admin_context(), ldb.Pool,
                                       pool['pool']['id'], 'ERROR', 'unknown')
             updated_pool = self.plugin.get_pool(context.get_admin_context(),
                                                 pool['pool']['id'])
-            self.assertEqual('ERROR', updated_pool['status'])
-            self.assertEqual('unknown', updated_pool['status_description'])
+            self.assertEqual(updated_pool['status'], 'ERROR')
+            self.assertEqual(updated_pool['status_description'], 'unknown')
 
             # update status to ACTIVE, status_description should be cleared
             self.plugin.update_status(context.get_admin_context(), ldb.Pool,
                                       pool['pool']['id'], 'ACTIVE')
             updated_pool = self.plugin.get_pool(context.get_admin_context(),
                                                 pool['pool']['id'])
-            self.assertEqual('ACTIVE', updated_pool['status'])
+            self.assertEqual(updated_pool['status'], 'ACTIVE')
             self.assertFalse(updated_pool['status_description'])
 
     def test_update_pool_health_monitor(self):
@@ -1604,7 +1582,7 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 context.get_admin_context(),
                 hm['health_monitor']['id'],
                 pool['pool']['id'])
-            self.assertEqual('PENDING_CREATE', assoc['status'])
+            self.assertEqual(assoc['status'], 'PENDING_CREATE')
             self.assertIsNone(assoc['status_description'])
 
             self.plugin.update_pool_health_monitor(
@@ -1616,8 +1594,8 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
                 context.get_admin_context(),
                 hm['health_monitor']['id'],
                 pool['pool']['id'])
-            self.assertEqual('ACTIVE', assoc['status'])
-            self.assertEqual('ok', assoc['status_description'])
+            self.assertEqual(assoc['status'], 'ACTIVE')
+            self.assertEqual(assoc['status_description'], 'ok')
 
     def test_check_orphan_pool_associations(self):
         with contextlib.nested(
@@ -1628,13 +1606,14 @@ class TestLoadBalancer(LoadBalancerPluginDbTestCase):
             #checking that 3 associations exist
             ctx = context.get_admin_context()
             qry = ctx.session.query(sdb.ProviderResourceAssociation)
-            self.assertEqual(2, qry.count())
+            self.assertEqual(qry.count(), 2)
             #removing driver
-            self.set_override([
-                constants.LOADBALANCER +
-                ':lbaas1:' + NOOP_DRIVER_KLASS +
-                ':default'
-            ])
+            cfg.CONF.set_override('service_provider',
+                                  [constants.LOADBALANCER +
+                                   ':lbaas1:' + NOOP_DRIVER_KLASS +
+                                   ':default'],
+                                  'service_providers')
+            sdb.ServiceTypeManager._instance = None
             # calling _remove_orphan... in constructor
             self.assertRaises(
                 SystemExit,
